@@ -80,6 +80,7 @@ MAP_TYPE = (
     keyword("map")("op") + LB + delimited_list(simple_types("params")) + RB
 ) / to_json_call
 ARRAY_TYPE = (keyword("array")("op") + LB + simple_types("params") + RB) / to_json_call
+JSON = Group(keyword("json")("op")) / to_json_call
 
 DATE = keyword("date")
 DATETIME = keyword("datetime")
@@ -126,6 +127,7 @@ simple_types << MatchFirst([
     INT,
     INT32,
     INT64,
+    JSON,
     NCHAR,
     NUMBER,
     NUMERIC,
